@@ -44,7 +44,7 @@ class CenterColumnShieldFlatTopHyperbola(RotateMixedShape):
         rotation_angle=360,
         stp_filename="CenterColumnFlatTopHyperbola.stp",
         stl_filename="CenterColumnFlatTopHyperbola.stl",
-        color=None,
+        color=(0.5, 0.5, 0.5),
         name="center_column",
         material_tag="center_column_shield_mat",
         azimuth_placement_angle=0,
@@ -84,14 +84,7 @@ class CenterColumnShieldFlatTopHyperbola(RotateMixedShape):
         self.outer_radius = outer_radius
         self.inner_radius = inner_radius
 
-    @property
-    def points(self):
         self.find_points()
-        return self._points
-
-    @points.setter
-    def points(self, points):
-        self._points = points
 
     @property
     def height(self):
@@ -166,8 +159,7 @@ class CenterColumnShieldFlatTopHyperbola(RotateMixedShape):
             (self.mid_radius, 0, "spline"),
             (self.outer_radius, -self.arc_height / 2, "straight"),
             (self.outer_radius, -self.height / 2, "straight"),
-            (self.inner_radius, -self.height / 2, "straight"),
-            (self.inner_radius, 0, "straight"),
+            (self.inner_radius, -self.height / 2, "straight")
         ]
 
         self.points = points
