@@ -82,7 +82,7 @@ class ITERtypeDivertor(RotateMixedShape):
         stp_filename="ITERtypeDivertor.stp",
         stl_filename="ITERtypeDivertor.stl",
         azimuth_placement_angle=0,
-        color=None,
+        color=(0.5, 0.5, 0.5),
         name=None,
         material_tag=None,
         **kwargs
@@ -126,14 +126,7 @@ class ITERtypeDivertor(RotateMixedShape):
         self.dome_pos = dome_pos
         self.dome_thickness = dome_thickness
 
-    @property
-    def points(self):
         self.find_points()
-        return self._points
-
-    @points.setter
-    def points(self, points):
-        self._points = points
 
     def create_vertical_target_points(
             self, anchor, coverage, tilt, radius, length):
@@ -311,7 +304,6 @@ class ITERtypeDivertor(RotateMixedShape):
 
         # append all points
         points = IVT_points + dome_points + OVT_points + casing_points
-        points.append(points[0])  # close surface
         self.points = points
 
 
@@ -353,7 +345,7 @@ class ITERtypeDivertorNoDome(ITERtypeDivertor):
         stp_filename=None,
         azimuth_placement_angle=0,
         solid=None,
-        color=None,
+        color=(0.5, 0.5, 0.5),
         name=None,
         material_tag=None,
         cut=None,
