@@ -49,7 +49,7 @@ class ToroidalFieldCoilRectangle(ExtrudeStraightShape):
         rotation_angle=360,
         stp_filename="ToroidalFieldCoilRectangle.stp",
         stl_filename="ToroidalFieldCoilRectangle.stl",
-        color=None,
+        color=(0.5, 0.5, 0.5),
         azimuth_placement_angle=0,
         name=None,
         material_tag="outer_tf_coil_mat",
@@ -90,23 +90,8 @@ class ToroidalFieldCoilRectangle(ExtrudeStraightShape):
         self.distance = distance
         self.number_of_coils = number_of_coils
 
-    @property
-    def points(self):
         self.find_points()
-        return self._points
-
-    @points.setter
-    def points(self, points):
-        self._points = points
-
-    @property
-    def azimuth_placement_angle(self):
         self.find_azimuth_placement_angle()
-        return self._azimuth_placement_angle
-
-    @azimuth_placement_angle.setter
-    def azimuth_placement_angle(self, azimuth_placement_angle):
-        self._azimuth_placement_angle = azimuth_placement_angle
 
     def find_points(self):
         """Finds the XZ points joined by straight connections that describe the 2D
@@ -139,6 +124,11 @@ class ToroidalFieldCoilRectangle(ExtrudeStraightShape):
     def find_azimuth_placement_angle(self):
         """Calculates the azimuth placement angles based on the number of tf coils"""
 
-        angles = np.linspace(0, 360, self.number_of_coils, endpoint=False)
+        angles = list(
+            np.linspace(
+                0,
+                360,
+                self.number_of_coils,
+                endpoint=False))
 
         self.azimuth_placement_angle = angles
