@@ -34,7 +34,7 @@ class RotateStraightShape(Shape):
         points,
         workplane="XZ",
         name=None,
-        color=None,
+        color=(0.5, 0.5, 0.5),
         material_tag=None,
         stp_filename="RotateStraightShape.stp",
         stl_filename="RotateStraightShape.stl",
